config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

#config etc/rc.d/rc.openldap

for i in ldap slapd
do
	config etc/openldap/$i.conf.new
done

for i in corba core cosine inetorgperson java misc nis openldap
do
 	config etc/openldap/schema/$i.schema.new
done

# If the ldap user/group don't exist, add them:
if grep "^ldap:x:" etc/passwd 1> /dev/null 2> /dev/null ; then
  true
else
  echo "ldap:x:80:80:ldap:/var/lib/openldap:" >> etc/passwd
fi
if grep "^ldap::" etc/group 1> /dev/null 2> /dev/null ; then
  true
else
  echo "ldap::80:ldap" >> etc/group
fi
if grep "^ldap:" etc/shadow 1> /dev/null 2> /dev/null ; then
  true
else
  echo "ldap:*:9797:0:::::" >> etc/shadow
fi

bin/chown -R ldap.ldap var/lib/openldap etc/openldap

( cd usr/lib ; rm -rf liblber-2.2.so.7 )
( cd usr/lib ; ln -sf liblber-2.2.so.7.0.19 liblber-2.2.so.7 )
( cd usr/lib ; rm -rf liblber.so )
( cd usr/lib ; ln -sf liblber-2.2.so.7.0.19 liblber.so )
( cd usr/lib ; rm -rf libldap-2.2.so.7 )
( cd usr/lib ; ln -sf libldap-2.2.so.7.0.19 libldap-2.2.so.7 )
( cd usr/lib ; rm -rf libldap.so )
( cd usr/lib ; ln -sf libldap-2.2.so.7.0.19 libldap.so )
( cd usr/lib ; rm -rf libldap_r-2.2.so.7 )
( cd usr/lib ; ln -sf libldap_r-2.2.so.7.0.19 libldap_r-2.2.so.7 )
( cd usr/lib ; rm -rf libldap_r.so )
( cd usr/lib ; ln -sf libldap_r-2.2.so.7.0.19 libldap_r.so )
( cd usr/libexec/openldap ; rm -rf back_dnssrv-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_dnssrv-2.2.so.7.0.19 back_dnssrv-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_dnssrv.so )
( cd usr/libexec/openldap ; ln -sf back_dnssrv-2.2.so.7.0.19 back_dnssrv.so )
( cd usr/libexec/openldap ; rm -rf back_hdb-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_hdb-2.2.so.7.0.19 back_hdb-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_hdb.so )
( cd usr/libexec/openldap ; ln -sf back_hdb-2.2.so.7.0.19 back_hdb.so )
( cd usr/libexec/openldap ; rm -rf back_meta-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_meta-2.2.so.7.0.19 back_meta-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_meta.so )
( cd usr/libexec/openldap ; ln -sf back_meta-2.2.so.7.0.19 back_meta.so )
( cd usr/libexec/openldap ; rm -rf back_monitor-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_monitor-2.2.so.7.0.19 back_monitor-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_monitor.so )
( cd usr/libexec/openldap ; ln -sf back_monitor-2.2.so.7.0.19 back_monitor.so )
( cd usr/libexec/openldap ; rm -rf back_null-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_null-2.2.so.7.0.19 back_null-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_null.so )
( cd usr/libexec/openldap ; ln -sf back_null-2.2.so.7.0.19 back_null.so )
( cd usr/libexec/openldap ; rm -rf back_passwd-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_passwd-2.2.so.7.0.19 back_passwd-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_passwd.so )
( cd usr/libexec/openldap ; ln -sf back_passwd-2.2.so.7.0.19 back_passwd.so )
( cd usr/libexec/openldap ; rm -rf back_shell-2.2.so.7 )
( cd usr/libexec/openldap ; ln -sf back_shell-2.2.so.7.0.19 back_shell-2.2.so.7 )
( cd usr/libexec/openldap ; rm -rf back_shell.so )
( cd usr/libexec/openldap ; ln -sf back_shell-2.2.so.7.0.19 back_shell.so )
( cd usr/sbin ; rm -rf slapadd )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slapadd )
( cd usr/sbin ; rm -rf slapcat )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slapcat )
( cd usr/sbin ; rm -rf slapdn )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slapdn )
( cd usr/sbin ; rm -rf slapindex )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slapindex )
( cd usr/sbin ; rm -rf slappasswd )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slappasswd )
( cd usr/sbin ; rm -rf slaptest )
( cd usr/sbin ; ln -sf /usr/libexec/slapd slaptest )
( cd usr/man/man1 ; rm -rf ldapadd.1 )
( cd usr/man/man1 ; ln -sf ldapmodify.1 ldapadd.1 )
( cd usr/man/man3 ; rm -rf ber_get_next.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_next.3 )
( cd usr/man/man3 ; rm -rf ber_skip_tag.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_skip_tag.3 )
( cd usr/man/man3 ; rm -rf ber_peek_tag.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_peek_tag.3 )
( cd usr/man/man3 ; rm -rf ber_scanf.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_scanf.3 )
( cd usr/man/man3 ; rm -rf ber_get_int.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_int.3 )
( cd usr/man/man3 ; rm -rf ber_get_stringa.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_stringa.3 )
( cd usr/man/man3 ; rm -rf ber_get_stringb.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_stringb.3 )
( cd usr/man/man3 ; rm -rf ber_get_null.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_null.3 )
( cd usr/man/man3 ; rm -rf ber_get_enum.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_enum.3 )
( cd usr/man/man3 ; rm -rf ber_get_boolean.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_boolean.3 )
( cd usr/man/man3 ; rm -rf ber_get_bitstring.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_get_bitstring.3 )
( cd usr/man/man3 ; rm -rf ber_first_element.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_first_element.3 )
( cd usr/man/man3 ; rm -rf ber_next_element.3 )
( cd usr/man/man3 ; ln -sf lber-decode.3 ber_next_element.3 )
( cd usr/man/man3 ; rm -rf ber_alloc_t.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_alloc_t.3 )
( cd usr/man/man3 ; rm -rf ber_flush.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_flush.3 )
( cd usr/man/man3 ; rm -rf ber_printf.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_printf.3 )
( cd usr/man/man3 ; rm -rf ber_put_int.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_int.3 )
( cd usr/man/man3 ; rm -rf ber_put_ostring.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_ostring.3 )
( cd usr/man/man3 ; rm -rf ber_put_string.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_string.3 )
( cd usr/man/man3 ; rm -rf ber_put_null.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_null.3 )
( cd usr/man/man3 ; rm -rf ber_put_enum.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_enum.3 )
( cd usr/man/man3 ; rm -rf ber_start_set.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_start_set.3 )
( cd usr/man/man3 ; rm -rf ber_put_seq.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_seq.3 )
( cd usr/man/man3 ; rm -rf ber_put_set.3 )
( cd usr/man/man3 ; ln -sf lber-encode.3 ber_put_set.3 )
( cd usr/man/man3 ; rm -rf ber_bvarray_add.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvarray_add.3 )
( cd usr/man/man3 ; rm -rf ber_bvarray_free.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvarray_free.3 )
( cd usr/man/man3 ; rm -rf ber_bvdup.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvdup.3 )
( cd usr/man/man3 ; rm -rf ber_bvecadd.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvecadd.3 )
( cd usr/man/man3 ; rm -rf ber_bvecfree.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvecfree.3 )
( cd usr/man/man3 ; rm -rf ber_bvfree.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvfree.3 )
( cd usr/man/man3 ; rm -rf ber_bvstr.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvstr.3 )
( cd usr/man/man3 ; rm -rf ber_bvstrdup.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_bvstrdup.3 )
( cd usr/man/man3 ; rm -rf ber_dupbv.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_dupbv.3 )
( cd usr/man/man3 ; rm -rf ber_free.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_free.3 )
( cd usr/man/man3 ; rm -rf ber_str2bv.3 )
( cd usr/man/man3 ; ln -sf lber-types.3 ber_str2bv.3 )
( cd usr/man/man3 ; rm -rf ldap_abandon_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_abandon.3 ldap_abandon_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_add_s.3 )
( cd usr/man/man3 ; ln -sf ldap_add.3 ldap_add_s.3 )
( cd usr/man/man3 ; rm -rf ldap_add_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_add.3 ldap_add_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_add_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_add.3 ldap_add_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_bind_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_bind_s.3 )
( cd usr/man/man3 ; rm -rf ldap_simple_bind.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_simple_bind.3 )
( cd usr/man/man3 ; rm -rf ldap_simple_bind_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_simple_bind_s.3 )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_sasl_bind.3 )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_sasl_bind_s.3 )
( cd usr/man/man3 ; rm -rf ldap_kerberos_bind_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_kerberos_bind_s.3 )
( cd usr/man/man3 ; rm -rf ldap_kerberos_bind1.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_kerberos_bind1.3 )
( cd usr/man/man3 ; rm -rf ldap_kerberos_bind1_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_kerberos_bind1_s.3 )
( cd usr/man/man3 ; rm -rf ldap_kerberos_bind2.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_kerberos_bind2.3 )
( cd usr/man/man3 ; rm -rf ldap_kerberos_bind2_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_kerberos_bind2_s.3 )
( cd usr/man/man3 ; rm -rf ldap_unbind.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_unbind.3 )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_unbind_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_unbind_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_unbind_s.3 )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_bind.3 ldap_unbind_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_compare_s.3 )
( cd usr/man/man3 ; ln -sf ldap_compare.3 ldap_compare_s.3 )
( cd usr/man/man3 ; rm -rf ldap_compare_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_compare.3 ldap_compare_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_compare_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_compare.3 ldap_compare_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_delete_s.3 )
( cd usr/man/man3 ; ln -sf ldap_delete.3 ldap_delete_s.3 )
( cd usr/man/man3 ; rm -rf ldap_delete_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_delete.3 ldap_delete_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_delete_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_delete.3 ldap_delete_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_perror.3 )
( cd usr/man/man3 ; ln -sf ldap_error.3 ldap_perror.3 )
( cd usr/man/man3 ; rm -rf ld_errno.3 )
( cd usr/man/man3 ; ln -sf ldap_error.3 ld_errno.3 )
( cd usr/man/man3 ; rm -rf ldap_result2error.3 )
( cd usr/man/man3 ; ln -sf ldap_error.3 ldap_result2error.3 )
( cd usr/man/man3 ; rm -rf ldap_errlist.3 )
( cd usr/man/man3 ; ln -sf ldap_error.3 ldap_errlist.3 )
( cd usr/man/man3 ; rm -rf ldap_err2string.3 )
( cd usr/man/man3 ; ln -sf ldap_error.3 ldap_err2string.3 )
( cd usr/man/man3 ; rm -rf ldap_next_attribute.3 )
( cd usr/man/man3 ; ln -sf ldap_first_attribute.3 ldap_next_attribute.3 )
( cd usr/man/man3 ; rm -rf ldap_next_entry.3 )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3 ldap_next_entry.3 )
( cd usr/man/man3 ; rm -rf ldap_count_entries.3 )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3 ldap_count_entries.3 )
( cd usr/man/man3 ; rm -rf ldap_next_message.3 )
( cd usr/man/man3 ; ln -sf ldap_first_message.3 ldap_next_message.3 )
( cd usr/man/man3 ; rm -rf ldap_count_messages.3 )
( cd usr/man/man3 ; ln -sf ldap_first_message.3 ldap_count_messages.3 )
( cd usr/man/man3 ; rm -rf ldap_next_reference.3 )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3 ldap_next_reference.3 )
( cd usr/man/man3 ; rm -rf ldap_count_references.3 )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3 ldap_count_references.3 )
( cd usr/man/man3 ; rm -rf ldap_explode_dn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_explode_dn.3 )
( cd usr/man/man3 ; rm -rf ldap_explode_rdn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_explode_rdn.3 )
( cd usr/man/man3 ; rm -rf ldap_dn2ufn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_dn2ufn.3 )
( cd usr/man/man3 ; rm -rf ldap_str2dn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_str2dn.3 )
( cd usr/man/man3 ; rm -rf ldap_dn2str.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_dn2str.3 )
( cd usr/man/man3 ; rm -rf ldap_dn2dcedn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_dn2dcedn.3 )
( cd usr/man/man3 ; rm -rf ldap_dcedn2dn.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_dcedn2dn.3 )
( cd usr/man/man3 ; rm -rf ldap_dn2ad_canonical.3 )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3 ldap_dn2ad_canonical.3 )
( cd usr/man/man3 ; rm -rf ldap_get_values_len.3 )
( cd usr/man/man3 ; ln -sf ldap_get_values.3 ldap_get_values_len.3 )
( cd usr/man/man3 ; rm -rf ldap_value_free.3 )
( cd usr/man/man3 ; ln -sf ldap_get_values.3 ldap_value_free.3 )
( cd usr/man/man3 ; rm -rf ldap_value_free_len.3 )
( cd usr/man/man3 ; ln -sf ldap_get_values.3 ldap_value_free_len.3 )
( cd usr/man/man3 ; rm -rf ldap_count_values.3 )
( cd usr/man/man3 ; ln -sf ldap_get_values.3 ldap_count_values.3 )
( cd usr/man/man3 ; rm -rf ldap_count_values_len.3 )
( cd usr/man/man3 ; ln -sf ldap_get_values.3 ldap_count_values_len.3 )
( cd usr/man/man3 ; rm -rf ldap_modify_s.3 )
( cd usr/man/man3 ; ln -sf ldap_modify.3 ldap_modify_s.3 )
( cd usr/man/man3 ; rm -rf ldap_modify_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_modify.3 ldap_modify_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_modify_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_modify.3 ldap_modify_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_mods_free.3 )
( cd usr/man/man3 ; ln -sf ldap_modify.3 ldap_mods_free.3 )
( cd usr/man/man3 ; rm -rf ldap_modrdn_s.3 )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3 ldap_modrdn_s.3 )
( cd usr/man/man3 ; rm -rf ldap_modrdn2.3 )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3 ldap_modrdn2.3 )
( cd usr/man/man3 ; rm -rf ldap_modrdn2_s.3 )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3 ldap_modrdn2_s.3 )
( cd usr/man/man3 ; rm -rf ldap_init.3 )
( cd usr/man/man3 ; ln -sf ldap_open.3 ldap_init.3 )
( cd usr/man/man3 ; rm -rf ldap_parse_sasl_bind_result.3 )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3 ldap_parse_sasl_bind_result.3 )
( cd usr/man/man3 ; rm -rf ldap_parse_extended_result.3 )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3 ldap_parse_extended_result.3 )
( cd usr/man/man3 ; rm -rf ldap_msgfree.3 )
( cd usr/man/man3 ; ln -sf ldap_result.3 ldap_msgfree.3 )
( cd usr/man/man3 ; rm -rf ldap_msgtype.3 )
( cd usr/man/man3 ; ln -sf ldap_result.3 ldap_msgtype.3 )
( cd usr/man/man3 ; rm -rf ldap_msgid.3 )
( cd usr/man/man3 ; ln -sf ldap_result.3 ldap_msgid.3 )
( cd usr/man/man3 ; rm -rf ldap_str2syntax.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_str2syntax.3 )
( cd usr/man/man3 ; rm -rf ldap_syntax2str.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_syntax2str.3 )
( cd usr/man/man3 ; rm -rf ldap_syntax2name.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_syntax2name.3 )
( cd usr/man/man3 ; rm -rf ldap_syntax_free.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_syntax_free.3 )
( cd usr/man/man3 ; rm -rf ldap_str2matchingrule.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_str2matchingrule.3 )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2str.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_matchingrule2str.3 )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2name.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_matchingrule2name.3 )
( cd usr/man/man3 ; rm -rf ldap_matchingrule_free.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_matchingrule_free.3 )
( cd usr/man/man3 ; rm -rf ldap_str2attributetype.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_str2attributetype.3 )
( cd usr/man/man3 ; rm -rf ldap_attributetype2str.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_attributetype2str.3 )
( cd usr/man/man3 ; rm -rf ldap_attributetype2name.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_attributetype2name.3 )
( cd usr/man/man3 ; rm -rf ldap_attributetype_free.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_attributetype_free.3 )
( cd usr/man/man3 ; rm -rf ldap_str2objectclass.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_str2objectclass.3 )
( cd usr/man/man3 ; rm -rf ldap_objectclass2str.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_objectclass2str.3 )
( cd usr/man/man3 ; rm -rf ldap_objectclass2name.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_objectclass2name.3 )
( cd usr/man/man3 ; rm -rf ldap_objectclass_free.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_objectclass_free.3 )
( cd usr/man/man3 ; rm -rf ldap_scherr2str.3 )
( cd usr/man/man3 ; ln -sf ldap_schema.3 ldap_scherr2str.3 )
( cd usr/man/man3 ; rm -rf ldap_search_s.3 )
( cd usr/man/man3 ; ln -sf ldap_search.3 ldap_search_s.3 )
( cd usr/man/man3 ; rm -rf ldap_search_st.3 )
( cd usr/man/man3 ; ln -sf ldap_search.3 ldap_search_st.3 )
( cd usr/man/man3 ; rm -rf ldap_search_ext.3 )
( cd usr/man/man3 ; ln -sf ldap_search.3 ldap_search_ext.3 )
( cd usr/man/man3 ; rm -rf ldap_search_ext_s.3 )
( cd usr/man/man3 ; ln -sf ldap_search.3 ldap_search_ext_s.3 )
( cd usr/man/man3 ; rm -rf ldap_sort_entries.3 )
( cd usr/man/man3 ; ln -sf ldap_sort.3 ldap_sort_entries.3 )
( cd usr/man/man3 ; rm -rf ldap_sort_values.3 )
( cd usr/man/man3 ; ln -sf ldap_sort.3 ldap_sort_values.3 )
( cd usr/man/man3 ; rm -rf ldap_sort_strcasecmp.3 )
( cd usr/man/man3 ; ln -sf ldap_sort.3 ldap_sort_strcasecmp.3 )
( cd usr/man/man3 ; rm -rf ldap_is_ldap_url.3 )
( cd usr/man/man3 ; ln -sf ldap_url.3 ldap_is_ldap_url.3 )
( cd usr/man/man3 ; rm -rf ldap_url_parse.3 )
( cd usr/man/man3 ; ln -sf ldap_url.3 ldap_url_parse.3 )
( cd usr/man/man3 ; rm -rf ldap_free_urldesc.3 )
( cd usr/man/man3 ; ln -sf ldap_url.3 ldap_free_urldesc.3 )
( cd usr/man/man5 ; rm -rf slapd-hdb.5 )
( cd usr/man/man5 ; ln -sf slapd-bdb.5 slapd-hdb.5 )
